@@ -6,8 +6,8 @@ use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.20_05'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.24_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
 
@@ -26,7 +26,7 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.20_05
+version 0.24_01
 
 =head1 SYNOPSIS
 
@@ -86,7 +86,11 @@ Check that a library is available for FFI
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Petr Pisar (ppisar)
 
 =head1 COPYRIGHT AND LICENSE
 
